Transform

Trait Transform 

pub trait Transform<V> {
    // Required method
    fn apply_point(&self, point: V) -> V;
}
A transformation that maps vectors to vectors.

Math libraries can implement this for their transform types (matrices, quaternions, rotors, etc.) to enable generic transform support across libraries that depend on vector-space.

Required Methods

fn apply_point(&self, point: V) -> V

Applies this transformation to a point.

Implementors